#pragma once
#include <sqlite3.h>
#include <stdbool.h>
#include <stdio.h>
#include <sys/types.h>

/*
 * command parsing
 */

enum KLIST_LOG_LEVEL {
  KLIST_LOG_ERROR,
  KLIST_LOG_WARNING,
  KLIST_LOG_INFO,
  KLIST_LOG_DEBUG
};
typedef enum KLIST_LOG_LEVEL KLIST_LOG_LEVEL;

struct klist_logging_ctx {
  KLIST_LOG_LEVEL log_level;
  FILE *log_target;
};

typedef struct klist_logging_ctx klist_logging_ctx;

struct klist {
  sqlite3 *db;
  sqlite3_stmt **stmts;
  int error;
  klist_logging_ctx *log_ctx;
};
typedef struct klist klist;

klist *klist_init(char *db);
void klist_deinit(klist *list);

/*
 * sql preparations
 */

void klist_sql_prepare(klist *, char *);

/*
 * assuring things
 */

bool klist_assure_user(const klist *, __uid_t, const char *);
void klist_assure_list(klist *, char *);
void klist_assure_task(klist *, char *);

/*
 * printing methods
 *
 * json printing will be implemented eventually
 */

void klist_print(klist_logging_ctx *, KLIST_LOG_LEVEL, const char *, ...);